@@ -14,7 +14,9 @@
 # limitations under the License.
 
 import os
+import re
 import shlex
+import shutil
 import subprocess
 
 from clade.extensions.compiler import Compiler
@@ -27,11 +29,29 @@ class CC(Compiler):
     __version__ = "1"
 
     def parse(self, cmds_file):
-        super().parse(cmds_file, self.conf.get("CC.which_list", []))
+        which_list = list(self.conf.get("CC.which_list", []))
+
+        if self.conf.get("CC.process_ccache"):
+            which_list.append("ccache")
+
+        super().parse(cmds_file, which_list)
 
     def parse_cmd(self, cmd):
         cmd_id = cmd["id"]
 
+        # Some commands can be ccache commands
+        if cmd["which"].endswith("ccache"):
+            cmd["command"] = [x for x in cmd["command"][1:] if x != "--ccache-skip"]
+            cmd["which"] = shutil.which(cmd["command"][0])
+
+            # Not all ccache commands are CC commands
+            for which in self.conf.get(self.name + ".which_list", []):
+                if re.search(which, cmd["which"]):
+                    break
+            else:
+                self.debug(f"{cmd} is not a {self.name} command")
+                return
+
         parsed_cmd = super().parse_cmd(cmd, self.name)
 
         if not parsed_cmd["out"] and "-c" in parsed_cmd["opts"]:
